# entsoe-py
Python client for the ENTSO-E API (european network of transmission system operators for electricity)

Documentation of the API found on https://transparency.entsoe.eu/content/static_content/Static%20content/web%20api/Guide.html


### Notes
When querying Day-Ahead prices, the country codes 'DE' and 'LU' are mapped to the 'DE-AT-LU' bidding zone